@@ -40,6 +40,7 @@ MOBILITY_COVARIATES_GPR_OUTPUT_ROOT = MOBILITY_COVARIATES_OUTPUT_ROOT / 'gpr_out
 MODEL_COMPARISON_INPUTS_ROOT = COVID_19 / 'model-comparison-inputs'
 MODEL_INPUTS_ROOT = COVID_19 / 'model-inputs'
 MORTALITY_AGE_PATTERN_ROOT = COVID_19 / 'mortality-age-pattern'
+MORTALITY_SCALARS_ROOT = COVID_19 / 'mortality-scalars'
 PAST_INFECTIONS_ROOT = COVID_19 / 'past-infections'
 PNEUMONIA_OUTPUT_ROOT = COVID_19 / 'pneumonia'
 POPULATION_DENSITY_OUTPUT_ROOT = COVID_19 / 'population-density'
@@ -49,8 +50,10 @@ SEIR_COUNTERFACTUAL_ROOT = COVID_19 / 'seir-counterfactual'
 SEIR_COVARIATE_PRIORS_ROOT = COVID_19 / 'seir-covariate-priors'
 SEIR_COVARIATES_OUTPUT_ROOT = COVID_19 / 'seir-covariates'
 SEIR_DIAGNOSTICS_OUTPUTS = COVID_19 / 'seir-diagnostics'
+SEIR_FIT_ROOT = COVID_19 / 'seir-fit'
 SEIR_FORECAST_OUTPUTS = COVID_19 / 'seir-forecast'
 SEIR_FINAL_OUTPUTS = COVID_19 / 'seir-outputs'
+SEIR_PREPROCESS_ROOT = COVID_19 / 'seir-preprocess'
 SEIR_REGRESSION_OUTPUTS = COVID_19 / 'seir-regression'
 SHAPEFILE_ROOT = COVID_19 / 'shapefiles'
 SNAPSHOT_ROOT = COVID_19 / 'snapshot-data'
@@ -59,6 +62,7 @@ SYMPTOM_SURVEY_ROOT = COVID_19 / 'symptom-survey-data'
 TESTING_OUTPUT_ROOT = COVID_19 / 'testing-outputs'
 UNVERSIONED_INPUTS_ROOT = COVID_19 / 'unversioned-inputs'
 VACCINE_COVERAGE_OUTPUT_ROOT = COVID_19 / 'vaccine-coverage'
+VACCINE_EFFICACY_ROOT = COVID_19 / 'vaccine-efficacy'
 VARIANT_OUTPUT_ROOT = COVID_19 / 'variant-scaleup'
 VISIT_VOLUME_ROOT = COVID_19 / 'visit-volume/'
 WANING_IMMUNITY_OUTPUT_ROOT = COVID_19 / 'waning-immunity'
